(******************************************************************************
 *                             Patdiff                                        *
 *                                                                            *
 * Copyright (C) 2011- Jane Street Holding, LLC                               *
 *    Contact: opensource@janestreet.com                                      *
 *    WWW: http://www.janestreet.com/ocaml                                    *
 *                                                                            *
 *                                                                            *
 * This library is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU Lesser General Public                 *
 * License as published by the Free Software Foundation; either               *
 * version 2 of the License, or (at your option) any later version.           *
 *                                                                            *
 * This library is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU          *
 * Lesser General Public License for more details.                            *
 *                                                                            *
 * You should have received a copy of the GNU Lesser General Public           *
 * License along with this library; if not, write to the Free Software        *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  *
 *                                                                            *
 ******************************************************************************)

open Core.Std

let doc = "FILE Write default configuration file"

let main file =
  let sample = Text.Configuration.ansi_config in
  let delete =
    if Sys.file_exists_exn file then (
      printf "%s already exists. Overwrite? (y/n) %!" file;
      let resp = In_channel.input_line In_channel.stdin in
      let resp = Option.value ~default:"" resp in
      let resp = String.lowercase resp in
      match resp with
      | "yes" | "y" -> true
      | _ -> false
    ) else true in
  if delete then begin
    try
      Out_channel.with_file ~f:(fun oc -> Out_channel.output_string oc sample) file;
      printf "Default configuration written to %s\n%!" file;
    with e -> failwithf "Error: %s" (Exn.to_string e) ()
  end else begin
    printf "Configuration file not written!\n%!";
    exit 1;
  end
;;

