(******************************************************************************
 *                             Patdiff                                        *
 *                                                                            *
 * Copyright (C) 2011- Jane Street Holding, LLC                               *
 *    Contact: opensource@janestreet.com                                      *
 *    WWW: http://www.janestreet.com/ocaml                                    *
 *                                                                            *
 *                                                                            *
 * This library is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU Lesser General Public                 *
 * License as published by the Free Software Foundation; either               *
 * version 2 of the License, or (at your option) any later version.           *
 *                                                                            *
 * This library is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU          *
 * Lesser General Public License for more details.                            *
 *                                                                            *
 * You should have received a copy of the GNU Lesser General Public           *
 * License along with this library; if not, write to the Free Software        *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  *
 *                                                                            *
 ******************************************************************************)

open Core.Std
open Core_extended.Std

let files =
  let filter = function (name, _stats) ->
    let is_suf s = String.is_suffix name ~suffix:s in
    not (is_suf ".new" || is_suf ".res")
  in
  let options = { Find.Options.default with
    Find.Options.max_depth = Some 0;
    Find.Options.filter = Some filter;
  }
  in
  let infos = Find.find_all ~options "files" in
  List.map infos ~f:(fun (name, _stats) -> name)

let patdiff_cmd ~old_file ~new_file ~keep_ws ~latex =
  let flags = "-default -alt-old 'old' -alt-new 'new' -dont-produce-unified-lines" in
  let flags = if keep_ws then flags ^ " -keep-whitespace" else flags in
  let flags = if latex then flags ^ " -latex" else flags in
  sprintf "../bin/patdiff.exe %s %s %s" flags old_file new_file

let parse_filename_flags name =
  let flags = String.split name ~on:'.' in
  let is_flag s = List.exists flags ~f:(String.equal s) in
  let exit_code = if is_flag "same" then 0 else 1 in
  let keep_ws = is_flag "keep_ws" in
  let latex   = is_flag "latex"   in
  (exit_code, keep_ws, latex)
