(******************************************************************************
 *                             Patdiff                                        *
 *                                                                            *
 * Copyright (C) 2011- Jane Street Holding, LLC                               *
 *    Contact: opensource@janestreet.com                                      *
 *    WWW: http://www.janestreet.com/ocaml                                    *
 *                                                                            *
 *                                                                            *
 * This library is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU Lesser General Public                 *
 * License as published by the Free Software Foundation; either               *
 * version 2 of the License, or (at your option) any later version.           *
 *                                                                            *
 * This library is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU          *
 * Lesser General Public License for more details.                            *
 *                                                                            *
 * You should have received a copy of the GNU Lesser General Public           *
 * License along with this library; if not, write to the Free Software        *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  *
 *                                                                            *
 ******************************************************************************)

open Core.Std
open Core_extended.Std

let refresh_res ~old_file ~new_file ~keep_ws ~latex =
  let res_file = old_file ^ ".res" in
  let patdiff_cmd = Common.patdiff_cmd ~old_file ~new_file ~keep_ws ~latex in
  let p_cmd = sprintf "%s > %s" patdiff_cmd res_file in
  let p_exit = Unix.system p_cmd in
  match p_exit with
  | `Exited 1 | `Exited 0 ->
      printf "%s was refreshed\n%!" res_file
  | `Signaled _ | `Stopped _ | `Exited _ ->
      eprintf "\"%s\" command failed\n%!" p_cmd;
      eprintf "%s failed to be refreshed\n%!" res_file

let instance name =
  let _exit_code, keep_ws, latex = Common.parse_filename_flags name in
  let old_file = name in
  let new_file = name ^ ".new" in
  refresh_res ~old_file ~new_file ~keep_ws ~latex

let summary = "\
  Refresh the test results in the files directory

  Examples:
\t./refresh.exe
\t./refresh.exe files/empty1
\t./refresh.exe files/empty1 files/oneline_same files/swap"
let usage_arg = "[FILE1 ... FILEN]"
let init () = ()
let flags = []

let final () = function
  | [] -> None
  | files -> Some files
;;

let main args =
  let default = Common.files in
  let files = Option.value args ~default in
  List.iter files ~f:instance
;;

let cmd = Command.create ~summary ~usage_arg ~init ~flags ~final main

let () = Command.run cmd ~hash_bang_expand:true
  ~version:Version_util.Revision.multi
  ~build_info:Version_util.Revision.build_info
